# Contributing to siiRL

Thank you for considering contributing to siiRL!

We welcome contributions in various forms, including but not limited to:
- Reporting a bug
- Submitting a fix
- Discussing the current state of the code
- Proposing new features
- Becoming a maintainer
- Review pull requests
- Add/Improve documentation
- ...

## Getting Started

To get started, please fork the latest branch.

### Reporting Bugs

If you find a bug, please open an issue on our GitHub repository. When you are creating a bug report, please include as many details as possible. Fill out the required template, detailed information helps us resolve issues faster.

### Suggesting Enhancements

If you have an idea for a new feature or an enhancement to an existing one, please open an issue on our GitHub repository. This allows for a discussion with the community and the project maintainers.

### Pull Requests

We actively welcome your pull requests.

1. Fork the repo and create your branch from `main`.
2. If you've added code that should be tested, add tests.
3. If you've changed APIs, update the documentation.
4. Ensure the test suite passes.
5. Make sure your code lints.
6. Issue that pull request!

## Styleguides

### Git Commit Messages

- Use the present tense ("Add feature" not "Added feature").
- Use the imperative mood ("Move A to..." not "Moves A to...").
- Limit the first line to 72 characters or less.
- Reference issues and pull requests liberally after the first line.

<!-- ### Code Style

We use XXX for code formatting and XXX for linting. Before submitting your pull request, please make sure your code is formatted and linted.

```bash
# Auto-format your code
pip install black
black .

# Lint your code
pip install ruff
ruff .
``` -->

## Any questions?

Don't hesitate to contact us if you have any questions. You can reach out to us by opening an issue on GitHub.

We are excited to see your contributions! 